@@ -1,4 +1,4 @@
-from sentinel import Path
+from . import Path
 from shutil import copy2
 import os.path
 
